The site is optimized to take notes in multiple ways:

<ul>
   <li>Notes on specific <strong>papers</strong> in the <a href="https://github.com/{{ site.repository }}/tree/main/_papers" target="_blank">papers</a> folder. The Markdown file name should correspond with the BibTex key.</li>
   <li>Notes on higher level <strong>thrusts</strong> in the <a href="https://github.com/{{ site.repository }}/tree/main/_notes/thrusts" target="_blank">thrusts</a> notes folder. These files already exist.</li>
   <li>Notes on any specific <strong>topics</strong> by creating a markdown file in the <a href="https://github.com/{{ site.repository }}/tree/main/_notes" target="_blank">notes</a> folder. You can organize in subfolders however you like.</li>
   <li><a href="https://github.com/{{ site.repository }}/tree/main/_posts" target="_blank">Posts</a> are intended for any kind of more structured writeup that warrants a timestamp.</li>
</ul>
